@@ -34,7 +34,7 @@
 (custom-add-loads 'font-lock-faces '("font-lock"))
 (custom-add-loads 'i18n '("cus-edit"))
 (custom-add-loads 'custom-menu '("cus-edit"))
-(custom-add-loads 'fill '("simple" "fill"))
+(custom-add-loads 'fill '("simple" "modeline" "fill"))
 (custom-add-loads 'display '("modeline" "toolbar" "scrollbar" "auto-show"))
 (custom-add-loads 'terminals '("gnuserv"))
 (custom-add-loads 'mouse '("mouse" "mwheel"))
@@ -61,7 +61,7 @@
 (custom-add-loads 'info '("toolbar-items" "info"))
 (custom-add-loads 'wp '("printer" "cus-edit"))
 (custom-add-loads 'vc '("files"))
-(custom-add-loads 'keyboard '("cmdloop"))
+(custom-add-loads 'keyboard '("cmdloop" "modeline"))
 (custom-add-loads 'docs '("hyper-apropos" "info"))
 (custom-add-loads 'isearch '("isearch-mode"))
 (custom-add-loads 'gutter '("gutter" "gutter-items"))
@@ -78,7 +78,7 @@
 (custom-add-loads 'buffers-menu '("menubar-items"))
 (custom-add-loads 'external '("process" "cus-edit"))
 (custom-add-loads 'killing '("simple"))
-(custom-add-loads 'editing-basics '("cmdloop" "simple" "files" "lisp"))
+(custom-add-loads 'editing-basics '("cmdloop" "simple" "modeline" "files" "lisp"))
 (custom-add-loads 'ldap '("ldap"))
 (custom-add-loads 'extensions '("auto-show" "wid-edit"))
 (custom-add-loads 'faces '("faces" "wid-edit" "font" "cus-edit" "font-lock" "hyper-apropos" "info"))
@@ -89,5 +89,6 @@
 (custom-add-loads 'hyper-apropos-faces '("hyper-apropos"))
 (custom-add-loads 'windows '("window" "window-xemacs"))
 (custom-add-loads 'x '("x-faces" "gtk-faces"))
+(custom-add-loads 'abbrev-mode '("modeline"))
 
 ;;; custom-load.el ends here
