@@ -898,81 +898,7 @@ which will not be used as accelerators."
 	:style toggle
 	:selected (and (boundp 'smtpmail-debug-info) smtpmail-debug-info)
 	:active (and (boundp 'send-mail-function)
-		     (eq send-mail-function 'smtpmail-send-it))]
-       "---"
-       ("%_Open URLs With"
-	["%_Emacs-W3"
-	 (customize-set-variable 'browse-url-browser-function 'browse-url-w3)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-w3))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-w3)
-		      (fboundp 'w3-fetch))]
-	["%_Netscape"
-	 (customize-set-variable 'browse-url-browser-function
-				 'browse-url-netscape)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-netscape))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-netscape))]
-	["%_Mosaic"
-	 (customize-set-variable 'browse-url-browser-function
-				 'browse-url-mosaic)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-mosaic))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-mosaic))]
-	["Mosaic (%_CCI)"
-	 (customize-set-variable 'browse-url-browser-function 'browse-url-cci)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-cci))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-cci))]
-	["%_IXI Mosaic"
-	 (customize-set-variable 'browse-url-browser-function
-				 'browse-url-iximosaic)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-iximosaic))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-iximosaic))]
-	["%_Lynx (xterm)"
-	 (customize-set-variable 'browse-url-browser-function
-				 'browse-url-lynx-xterm)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-lynx-xterm))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-lynx-xterm))]
-	["L%_ynx (xemacs)"
-	 (customize-set-variable 'browse-url-browser-function
-				 'browse-url-lynx-emacs)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-lynx-emacs))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-lynx-emacs))]
-	["%_Grail"
-	 (customize-set-variable 'browse-url-browser-function
-				 'browse-url-grail)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-grail))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-grail))]
-	["%_Kfm"
-	 (customize-set-variable 'browse-url-browser-function
-				 'browse-url-kfm)
-	 :style radio
-	 :selected (and (boundp 'browse-url-browser-function)
-			(eq browse-url-browser-function 'browse-url-kfm))
-	 :active (and (boundp 'browse-url-browser-function)
-		      (fboundp 'browse-url-kfm))]
-	))
+		     (eq send-mail-function 'smtpmail-send-it))])
       ("%_Troubleshooting"
        ["%_Debug on Error"
 	(customize-set-variable 'debug-on-error (not debug-on-error))
