@@ -73,7 +73,7 @@ stream_init_console (struct console *con, Lisp_Object params)
 	   this descriptor. */
 	fopen ((char *) XSTRING_DATA (tty), READ_PLUS_TEXT);
       if (!stream_con->in)
-	error ("Unable to open tty %s", XSTRING_DATA (tty));
+	signal_error (Qio_error, "Unable to open tty", tty);
     }
 }
 
@@ -118,14 +118,14 @@ stream_delete_console (struct console *con)
 
 Lisp_Object
 stream_semi_canonicalize_console_connection (Lisp_Object connection,
-					     Error_behavior errb)
+					     Error_Behavior errb)
 {
   return NILP (connection) ? Vstdio_str : connection;
 }
 
 Lisp_Object
 stream_canonicalize_console_connection (Lisp_Object connection,
-					Error_behavior errb)
+					Error_Behavior errb)
 {
   if (NILP (connection) || internal_equal (connection, Vstdio_str, 0))
     return Vstdio_str;
@@ -143,14 +143,14 @@ stream_canonicalize_console_connection (Lisp_Object connection,
 
 Lisp_Object
 stream_semi_canonicalize_device_connection (Lisp_Object connection,
-					    Error_behavior errb)
+					    Error_Behavior errb)
 {
   return stream_semi_canonicalize_console_connection (connection, errb);
 }
 
 Lisp_Object
 stream_canonicalize_device_connection (Lisp_Object connection,
-				       Error_behavior errb)
+				       Error_Behavior errb)
 {
   return stream_canonicalize_console_connection (connection, errb);
 }
@@ -162,7 +162,7 @@ stream_init_frame_1 (struct frame *f, Lisp_Object props)
 #if 0
   struct device *d = XDEVICE (FRAME_DEVICE (f));
   if (!NILP (DEVICE_FRAME_LIST (d)))
-    error ("Only one frame allowed on stream devices");
+    invalid_operation ("Only one frame allowed on stream devices", Qunbound);
 #endif
   f->name = build_string ("stream");
   f->height = 80;
@@ -279,17 +279,17 @@ void
 vars_of_console_stream (void)
 {
   DEFVAR_LISP ("terminal-console", &Vterminal_console /*
-The initial console-object, which represents XEmacs' stdout.
+The initial console object, which represents XEmacs' stdout.
 */ );
   Vterminal_console = Qnil;
 
   DEFVAR_LISP ("terminal-device", &Vterminal_device /*
-The initial device-object, which represents XEmacs' stdout.
+The initial device object, which represents XEmacs' stdout.
 */ );
   Vterminal_device = Qnil;
 
   DEFVAR_LISP ("terminal-frame", &Vterminal_frame /*
-The initial frame-object, which represents XEmacs' stdout.
+The initial frame object, which represents XEmacs' stdout.
 */ );
   Vterminal_frame = Qnil;
 
