@@ -166,7 +166,7 @@ If FILES-ONLY is the symbol t, then only the "files" in the directory
 
 	  {
 	    Lisp_Object name =
-	      make_string ((Bufbyte *)dp->d_name, len);
+	      make_string ((Intbyte *)dp->d_name, len);
 	    if (!NILP (full))
 	      name = concat2 (directory, name);
 
@@ -356,13 +356,13 @@ file_name_completion (Lisp_Object file, Lisp_Object directory, int all_flag,
 	  Charcount cclen;
           int directoryp;
           int ignored_extension_p = 0;
-	  Bufbyte *d_name;
+	  Intbyte *d_name;
 
 	  dp = readdir (d);
 	  if (!dp) break;
 
-	  /* Cast to Bufbyte* is OK, as readdir() Mule-encapsulates.  */
-	  d_name = (Bufbyte *) dp->d_name;
+	  /* Cast to Intbyte* is OK, as readdir() Mule-encapsulates.  */
+	  d_name = (Intbyte *) dp->d_name;
 	  len = NAMLEN (dp);
 	  cclen = bytecount_to_charcount (d_name, len);
 
@@ -450,8 +450,8 @@ file_name_completion (Lisp_Object file, Lisp_Object directory, int all_flag,
           else
             {
               Charcount compare = min (bestmatchsize, cclen);
-              Bufbyte *p1 = XSTRING_DATA (bestmatch);
-              Bufbyte *p2 = d_name;
+              Intbyte *p1 = XSTRING_DATA (bestmatch);
+              Intbyte *p2 = d_name;
               Charcount matchsize = scmp (p1, p2, compare);
 
               if (matchsize < 0)
@@ -562,7 +562,7 @@ These are all the user names which begin with PARTIAL-USERNAME.
 
 struct user_name
 {
-  Bufbyte *ptr;
+  Intbyte *ptr;
   Bytecount len;
 };
 
@@ -729,7 +729,7 @@ user_name_completion (Lisp_Object user, int all_flag, int *uniq)
 
   for (i = 0; i < user_cache.length; i++)
     {
-      Bufbyte *u_name = user_cache.user_names[i].ptr;
+      Intbyte *u_name = user_cache.user_names[i].ptr;
       Bytecount len   = user_cache.user_names[i].len;
       /* scmp() works in chars, not bytes, so we have to compute this: */
       Charcount cclen = bytecount_to_charcount (u_name, len);
@@ -763,8 +763,8 @@ user_name_completion (Lisp_Object user, int all_flag, int *uniq)
       else
         {
           Charcount compare = min (bestmatchsize, cclen);
-          Bufbyte *p1 = XSTRING_DATA (bestmatch);
-          Bufbyte *p2 = u_name;
+          Intbyte *p1 = XSTRING_DATA (bestmatch);
+          Intbyte *p2 = u_name;
           Charcount matchsize = scmp_1 (p1, p2, compare, 0);
 
           if (matchsize < 0)
@@ -801,8 +801,8 @@ make_directory_hash_table (const char *path)
 	{
 	  Bytecount len = NAMLEN (dp);
 	  if (DIRENTRY_NONEMPTY (dp))
-	    /* Cast to Bufbyte* is OK, as readdir() Mule-encapsulates.  */
-	    Fputhash (make_string ((Bufbyte *) dp->d_name, len), Qt, hash);
+	    /* Cast to Intbyte* is OK, as readdir() Mule-encapsulates.  */
+	    Fputhash (make_string ((Intbyte *) dp->d_name, len), Qt, hash);
 	}
       closedir (d);
       return hash;
@@ -811,6 +811,9 @@ make_directory_hash_table (const char *path)
     return Qnil;
 }
 
+#if 0
+/* ... never used ... should use list2 directly anyway ... */
+/* NOTE: This function can never return a negative value. */
 Lisp_Object
 wasteful_word_to_lisp (unsigned int item)
 {
@@ -820,6 +823,7 @@ wasteful_word_to_lisp (unsigned int item)
   XCDR (cons) = Fcons (XCDR (cons), Qnil);
   return cons;
 }
+#endif
 
 DEFUN ("file-attributes", Ffile_attributes, 1, 1, 0, /*
 Return a list of attributes of file FILENAME.
@@ -906,16 +910,16 @@ If file does not exist, returns nil.
   values[1] = make_int (s.st_nlink);
   values[2] = make_int (s.st_uid);
   values[3] = make_int (s.st_gid);
-  values[4] = wasteful_word_to_lisp (s.st_atime);
-  values[5] = wasteful_word_to_lisp (s.st_mtime);
-  values[6] = wasteful_word_to_lisp (s.st_ctime);
+  values[4] = make_time (s.st_atime);
+  values[5] = make_time (s.st_mtime);
+  values[6] = make_time (s.st_ctime);
   values[7] = make_int ((EMACS_INT) s.st_size);
   /* If the size is out of range, give back -1.  */
   /* #### Fix when Emacs gets bignums! */
   if (XINT (values[7]) != s.st_size)
     values[7] = make_int (-1);
   filemodestring (&s, modes);
-  values[8] = make_string ((Bufbyte *) modes, 10);
+  values[8] = make_string ((Intbyte *) modes, 10);
 #if defined (BSD4_2) || defined (BSD4_3)	/* file gid will be dir gid */
   {
     struct stat sdir;
