@@ -45,7 +45,7 @@ Boston, MA 02111-1307, USA.  */
 typedef struct
 {
   const void *varaddress;
-  Memory_Count size;
+  Bytecount size;
 } pdump_opaque;
 
 typedef struct
@@ -84,7 +84,7 @@ static Lisp_Object_ptr_dynarr *pdump_weak_object_chains;
 /* Mark SIZE bytes at non-heap address VARADDRESS for dumping as is,
    without any bit-twiddling. */
 void
-dump_add_opaque (const void *varaddress, Memory_Count size)
+dump_add_opaque (const void *varaddress, Bytecount size)
 {
   pdump_opaque info;
   info.varaddress = varaddress;
@@ -129,7 +129,7 @@ dump_add_weak_object_chain (Lisp_Object *varaddress)
 
 
 inline static void
-pdump_align_stream (FILE *stream, Memory_Count alignment)
+pdump_align_stream (FILE *stream, Bytecount alignment)
 {
   long offset = ftell (stream);
   long adjustment = ALIGN_SIZE (offset, alignment) - offset;
@@ -215,7 +215,7 @@ typedef struct
 
 char *pdump_start;
 char *pdump_end;
-static Memory_Count pdump_length;
+static Bytecount pdump_length;
 
 #ifdef WIN32_NATIVE
 /* Handle for the dump file */
@@ -235,7 +235,7 @@ static unsigned char pdump_align_table[] =
 };
 
 static inline int
-pdump_size_to_align (Memory_Count size)
+pdump_size_to_align (Bytecount size)
 {
   return pdump_align_table[size % countof (pdump_align_table)];
 }
@@ -244,7 +244,7 @@ typedef struct pdump_entry_list_elt
 {
   struct pdump_entry_list_elt *next;
   const void *obj;
-  Memory_Count size;
+  Bytecount size;
   int count;
   EMACS_INT save_offset;
 } pdump_entry_list_elt;
@@ -276,7 +276,7 @@ static pdump_struct_list pdump_struct_table;
 static int *pdump_alert_undump_object;
 
 static unsigned long cur_offset;
-static Memory_Count max_size;
+static Bytecount max_size;
 static int pdump_fd;
 static void *pdump_buf;
 static FILE *pdump_out;
@@ -313,7 +313,7 @@ pdump_get_entry (const void *obj)
 }
 
 static void
-pdump_add_entry (pdump_entry_list *list, const void *obj, Memory_Count size,
+pdump_add_entry (pdump_entry_list *list, const void *obj, Bytecount size,
 		 int count)
 {
   pdump_entry_list_elt *e;
@@ -423,14 +423,14 @@ pdump_get_indirect_count (EMACS_INT code,
   irdata = ((char *)idata) + idesc[line].offset;
   switch (idesc[line].type)
     {
-    case XD_MEMORY_COUNT:
-      count = *(Memory_Count *)irdata;
+    case XD_BYTECOUNT:
+      count = *(Bytecount *)irdata;
       break;
-    case XD_ELEMENT_COUNT:
-      count = *(Element_Count *)irdata;
+    case XD_ELEMCOUNT:
+      count = *(Elemcount *)irdata;
       break;
-    case XD_HASH_CODE:
-      count = *(Hash_Code *)irdata;
+    case XD_HASHCODE:
+      count = *(Hashcode *)irdata;
       break;
     case XD_INT:
       count = *(int *)irdata;
@@ -438,9 +438,6 @@ pdump_get_indirect_count (EMACS_INT code,
     case XD_LONG:
       count = *(long *)irdata;
       break;
-    case XD_BYTECOUNT:
-      count = *(Bytecount *)irdata;
-      break;
     default:
       stderr_out ("Unsupported count type : %d (line = %d, code=%ld)\n",
 		  idesc[line].type, line, (long)code);
@@ -471,12 +468,11 @@ pdump_register_sub (const void *data, const struct lrecord_description *desc, in
 	  pos = 0;
 	  desc = ((const Lisp_Specifier *)data)->methods->extra_description;
 	  goto restart;
-	case XD_MEMORY_COUNT:
-	case XD_ELEMENT_COUNT:
-	case XD_HASH_CODE:
+	case XD_BYTECOUNT:
+	case XD_ELEMCOUNT:
+	case XD_HASHCODE:
 	case XD_INT:
 	case XD_LONG:
-	case XD_BYTECOUNT:
 	case XD_INT_RESET:
 	case XD_LO_LINK:
 	  break;
@@ -634,7 +630,7 @@ static void
 pdump_dump_data (pdump_entry_list_elt *elt,
 		 const struct lrecord_description *desc)
 {
-  Memory_Count size = elt->size;
+  Bytecount size = elt->size;
   int count = elt->count;
   if (desc)
     {
@@ -653,12 +649,11 @@ pdump_dump_data (pdump_entry_list_elt *elt,
 		case XD_SPECIFIER_END:
 		  desc = ((const Lisp_Specifier *)(elt->obj))->methods->extra_description;
 		  goto restart;
-		case XD_MEMORY_COUNT:
-		case XD_ELEMENT_COUNT:
-		case XD_HASH_CODE:
+		case XD_BYTECOUNT:
+		case XD_ELEMCOUNT:
+		case XD_HASHCODE:
 		case XD_INT:
 		case XD_LONG:
-		case XD_BYTECOUNT:
 		  break;
 		case XD_INT_RESET:
 		  {
@@ -751,12 +746,11 @@ pdump_reloc_one (void *data, EMACS_INT delta,
 	  pos = 0;
 	  desc = ((const Lisp_Specifier *)data)->methods->extra_description;
 	  goto restart;
-	case XD_MEMORY_COUNT:
-	case XD_ELEMENT_COUNT:
-	case XD_HASH_CODE:
+	case XD_BYTECOUNT:
+	case XD_ELEMCOUNT:
+	case XD_HASHCODE:
 	case XD_INT:
 	case XD_LONG:
-	case XD_BYTECOUNT:
 	case XD_INT_RESET:
 	  break;
 	case XD_OPAQUE_DATA_PTR:
@@ -816,7 +810,7 @@ static void
 pdump_allocate_offset (pdump_entry_list_elt *elt,
 		       const struct lrecord_description *desc)
 {
-  Memory_Count size = elt->count * elt->size;
+  Bytecount size = elt->count * elt->size;
   elt->save_offset = cur_offset;
   if (size>max_size)
     max_size = size;
@@ -857,7 +851,7 @@ static void
 pdump_dump_root_struct_ptrs (void)
 {
   int i;
-  Element_Count count = Dynarr_length (pdump_root_struct_ptrs);
+  Elemcount count = Dynarr_length (pdump_root_struct_ptrs);
   pdump_static_pointer *data = alloca_array (pdump_static_pointer, count);
   for (i = 0; i < count; i++)
     {
@@ -933,11 +927,11 @@ pdump_dump_rtables (void)
 static void
 pdump_dump_root_objects (void)
 {
-  Element_Count count = (Dynarr_length (pdump_root_objects) +
+  Elemcount count = (Dynarr_length (pdump_root_objects) +
 			 Dynarr_length (pdump_weak_object_chains));
-  Element_Count i;
+  Elemcount i;
 
-  PDUMP_WRITE_ALIGNED (Element_Count, count);
+  PDUMP_WRITE_ALIGNED (Elemcount, count);
   PDUMP_ALIGN_OUTPUT (pdump_static_Lisp_Object);
 
   for (i = 0; i < Dynarr_length (pdump_root_objects); i++)
@@ -1155,7 +1149,7 @@ pdump_load_finish (void)
     }
 
   /* Put the pdump_root_objects variables in place */
-  i = PDUMP_READ_ALIGNED (p, Element_Count);
+  i = PDUMP_READ_ALIGNED (p, Elemcount);
   p = (char *) ALIGN_PTR (p, ALIGNOF (pdump_static_Lisp_Object));
   while (i--)
     {
@@ -1271,7 +1265,7 @@ pdump_resource_get (void)
 
   pdump_free = pdump_resource_free;
   pdump_length = SizeofResource (NULL, hRes);
-  if (pdump_length <= (Memory_Count) sizeof (pdump_header))
+  if (pdump_length <= (Bytecount) sizeof (pdump_header))
     {
       pdump_start = 0;
       return 0;
@@ -1304,7 +1298,7 @@ pdump_file_get (const char *path)
     return 0;
 
   pdump_length = lseek (fd, 0, SEEK_END);
-  if (pdump_length < (Memory_Count) sizeof (pdump_header))
+  if (pdump_length < (Bytecount) sizeof (pdump_header))
     {
       close (fd);
       return 0;
