@@ -266,9 +266,9 @@ tty_get_foreign_selection (Lisp_Object selection_symbol, Lisp_Object target_type
 
 	while (1)
 	{
-		Bufbyte tempbuf[1024]; /* some random amount */
-		Lstream_Data_Count i;
-		Lstream_Data_Count size_in_bytes =
+		Intbyte tempbuf[1024]; /* some random amount */
+		Bytecount i;
+		Bytecount size_in_bytes =
 		  Lstream_read (XLSTREAM (terminal_stream),
 				tempbuf, sizeof (tempbuf));
 
