@@ -350,12 +350,12 @@ enum LEADING_BYTE_OFFICIAL_1
   LEADING_BYTE_KATAKANA_JISX0201, /* 0x89 Right half of JIS X0201-1976 */
   LEADING_BYTE_LATIN_JISX0201,    /* 0x8A Left  half of JIS X0201-1976 */
   LEADING_BYTE_CYRILLIC_ISO8859_5,/* 0x8B Right half of ISO 8859-5 */
-  LEADING_BYTE_LATIN_ISO8859_9    /* 0x8C Right half of ISO 8859-9 */
-                                  /* 0x8D unused */
+  LEADING_BYTE_LATIN_ISO8859_9,   /* 0x8C Right half of ISO 8859-9 */
+  LEADING_BYTE_LATIN_ISO8859_15   /* 0x8D Right half of ISO 8859-15 */
 };
 
 #define MIN_LEADING_BYTE_OFFICIAL_1	LEADING_BYTE_LATIN_ISO8859_1
-#define MAX_LEADING_BYTE_OFFICIAL_1	LEADING_BYTE_LATIN_ISO8859_9
+#define MAX_LEADING_BYTE_OFFICIAL_1	LEADING_BYTE_LATIN_ISO8859_15
 
 /** The following are for 2-byte characters in an official charset. **/
 enum LEADING_BYTE_OFFICIAL_2
