@@ -30,8 +30,8 @@ Boston, MA 02111-1307, USA.  */
 #define realloc xrealloc
 #define malloc xmalloc
 #define free xfree
-extern void *xmalloc (Memory_Count size);
-extern void *xrealloc (void *, Memory_Count size);
+extern void *xmalloc (Bytecount size);
+extern void *xrealloc (void *, Bytecount size);
 
 /* Assuming STRING is the value of a termcap string entry
    containing `%' constructs to expand parameters,
